<?php

namespace FiloBlu\HabbyTest\Block\Adminhtml\System\Config;

use Magento\Framework\View\Element\Html\Select;
use Magento\Theme\Model\ResourceModel\Theme\CollectionFactory as ThemeCollectionFactory;

/**
 * Class RequestConditions
 * @package FiloBlu\HabbyTest\Block\Adminhtml\System\Config
 */
class RequestConditions extends \Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray
{
    /**
     * @var \Magento\Theme\Model\ResourceModel\Theme\CollectionFactory
     */
    protected $themeCollectionFactory;

    /**
     * RequestConditions constructor.
     * @param \Magento\Backend\Block\Template\Context $context
     * @param ThemeCollectionFactory $themeCollectionFactory
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        ThemeCollectionFactory $themeCollectionFactory,
        array $data = []
    )
    {
        $this->themeCollectionFactory = $themeCollectionFactory;
        parent::__construct($context, $data);
    }

    /**
     * @return array
     */
    protected function getThemeSelectValues()
    {
        $themes = [];
        /** @var \Magento\Theme\Model\ResourceModel\Theme\Collection $themeCollection */
        $themeCollection = $this->themeCollectionFactory->create();

        $themeCollection->addFieldToFilter('area', 'frontend');

        foreach ($themeCollection->getItems() as $theme) {
            $themes[] = ['label' => $theme->getThemeTitle(), 'value' => $theme->getCode()];
        }

        return $themes;
    }

    /**
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    protected function _prepareToRender()
    {
        $this->addColumn('theme', [
            'label' => __('Theme'),
            'renderer' => $this->getLayout()->createBlock(Select::class)
                ->setId($this->_getCellInputElementId('<%- _id %>', 'theme'))
                ->setName($this->_getCellInputElementName('theme'))
                ->setClass('select')
                ->setOptions($this->getThemeSelectValues())
        ]);

        $this->addColumn('param_name', ['label' => __('Query param name')]);
        $this->addColumn('param_value', ['label' => __('Query param value')]);

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add conditions');
    }
}
