<?php

namespace FiloBlu\HabbyTest\View;

use \Magento\Store\Model\ScopeInterface;
use \Magento\Framework\App\ObjectManager;
use \Magento\Framework\Serialize\Serializer\Json;

/**
 * Class DesignExceptions
 * @package FiloBlu\HabbyTest\View
 */
class DesignExceptions extends \Magento\Framework\View\DesignExceptions
{
    /**
     * @var string
     */
    const GENERAL_ENABLE = 'filoblu_habbytest/general/enable';

    /**
     * @var string
     */
    const GENERAL_CONDITIONS = 'filoblu_habbytest/general/conditions';

    /**
     * @var \Magento\Customer\Model\Session
     */
    protected $session;

    /**
     * DesignExceptions constructor.
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param \Magento\Customer\Model\Session $session
     * @param string $exceptionConfigPath
     * @param string $scopeType
     * @param Json|null $serializer
     */
    public function __construct(
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Customer\Model\Session $session,
         $exceptionConfigPath,
         $scopeType,
        Json $serializer = null
    ) {
        $this->session = $session;
       parent::__construct($scopeConfig, $exceptionConfigPath, $scopeType, $serializer);
    }

    /**
     * @param \Magento\Framework\App\Request\Http $request
     * @return bool|string
     */
    public function getThemeByRequest(\Magento\Framework\App\Request\Http $request)
    {
        if (($theme = $this->match($request)) !== null) {
            return $theme;
        }

        return parent::getThemeByRequest($request);
    }

    /**
     * @param \Magento\Framework\App\Request\Http $request
     * @return string|null
     */
    public function match(\Magento\Framework\App\Request\Http $request)
    {
        if (!$this->isEnabled()) {
            $this->session->unsHabbyTheme();
            return null;
        }

        if(!empty($theme = $this->session->getHabbyTheme()))
        {
            return $theme;
        }

        if(($conditions = $this->getConditions()) === false)
        {
            return null;
        }

        foreach ($conditions as $k => $condition) {

            if(empty($condition['theme']) || empty($condition['param_name'] || empty($condition['param_value'])))
            {
                continue;
            }

            $value = $request->getQueryValue($condition['param_name']);

            if($value === null || $value != $condition['param_name'])
            {
                continue;
            }

            $this->session->setHabbyTheme($condition['theme']);
            return $condition['theme'];
        }

        return null;
    }

    /**
     * @return mixed
     */
    public function isEnabled()
    {
        return $this->scopeConfig->getValue(self::GENERAL_ENABLE, ScopeInterface::SCOPE_STORE);
    }

    /**
     * Check if value is a serialized string
     *
     * @param string $value
     * @return boolean
     */
    private function isSerialized($value)
    {
        return (boolean)preg_match('/^((s|i|d|b|a|O|C):|N;)/', $value);
    }

    /**
     * @return bool
     */
    public function getConditions()
    {
        $value = $this->scopeConfig->getValue(self::GENERAL_CONDITIONS, ScopeInterface::SCOPE_STORE);

        if (empty($value)) {
            return false;
        }
        if ($this->isSerialized($value)) {
            $unserializer = ObjectManager::getInstance()->get(\Magento\Framework\Unserialize\Unserialize::class);
        } else {
            $unserializer = ObjectManager::getInstance()->get(\Magento\Framework\Serialize\Serializer\Json::class);
        }

        return $unserializer->unserialize($value);
    }

}